@@ -352,12 +352,6 @@ class interface(abstract_interface):
            
         return
 
-    def close(self):
-        if (self.instrument.connected == True):
-            self.disconnect_device()
-        if self.gui.plot_window:
-            self.gui.plot_window.close()
-
     ### END Functions to talk with low-level driver
     
     
@@ -501,15 +495,7 @@ class gui():
         self.plot_window.setWindowTitle(f"Powermeter: {self.interface.connected_device_name}")
         self.plot_window.show()
         self.plot_window.setHidden(True)
-     
-    def disable_widget(self,widgets):
-        for widget in widgets:
-            widget.setEnabled(False)   
-
-    def enable_widget(self,widgets):
-        for widget in widgets:
-            widget.setEnabled(True) 
-        
+            
     def set_disconnected_state(self):
         self.disable_widget(self.widgets_enabled_when_connected)
         self.enable_widget(self.widgets_enabled_when_disconnected)
